@@ -2,13 +2,12 @@ package Physics::Unit::Acceleration;
 use strict;
 use Physics::Unit::Scalar;
 use vars qw( $VERSION @ISA $MyUnit );
-$VERSION = '0.04_01';
-$VERSION = eval $VERSION;
-
+$VERSION = '0.01';
 @ISA = qw( Physics::Unit::Scalar );
 
 $MyUnit = GetUnit('m/s^2');
 
+1;
 
 package Physics::Unit::Area;
 use strict;
@@ -18,6 +17,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('are');
 
+1;
 
 package Physics::Unit::Capacitance;
 use strict;
@@ -27,6 +27,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('farad');
 
+1;
 
 package Physics::Unit::Charge;
 use strict;
@@ -36,6 +37,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('coulomb');
 
+1;
 
 package Physics::Unit::Conductance;
 use strict;
@@ -45,6 +47,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('siemens');
 
+1;
 
 package Physics::Unit::Current;
 use strict;
@@ -54,6 +57,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('ampere');
 
+1;
 
 package Physics::Unit::Data;
 use strict;
@@ -63,7 +67,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('bit');
 
-
+1;
 package Physics::Unit::Distance;
 use strict;
 use Physics::Unit::Scalar;
@@ -72,6 +76,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('meter');
 
+1;
 
 package Physics::Unit::Dose;
 use strict;
@@ -81,6 +86,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('gray');
 
+1;
 
 package Physics::Unit::Dimensionless;
 use strict;
@@ -90,6 +96,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('unity');
 
+1;
 
 package Physics::Unit::Electric_potential;
 use strict;
@@ -99,6 +106,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('volt');
 
+1;
 
 package Physics::Unit::Energy;
 use strict;
@@ -108,6 +116,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('joule');
 
+1;
 
 package Physics::Unit::Force;
 use strict;
@@ -117,6 +126,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('newton');
 
+1;
 
 package Physics::Unit::Frequency;
 use strict;
@@ -126,6 +136,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('hertz');
 
+1;
 
 package Physics::Unit::Inductance;
 use strict;
@@ -135,6 +146,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('henry');
 
+1;
 
 package Physics::Unit::Luminosity;
 use strict;
@@ -144,6 +156,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('candela');
 
+1;
 
 package Physics::Unit::Magnetic_field;
 use strict;
@@ -153,6 +166,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('tesla');
 
+1;
 
 package Physics::Unit::Magnetic_flux;
 use strict;
@@ -162,6 +176,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('weber');
 
+1;
 
 package Physics::Unit::Mass;
 use strict;
@@ -171,6 +186,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('gram');
 
+1;
 
 package Physics::Unit::Money;
 use strict;
@@ -190,6 +206,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('watt');
 
+1;
 
 package Physics::Unit::Pressure;
 use strict;
@@ -199,6 +216,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('pascal');
 
+1;
 
 package Physics::Unit::Resistance;
 use strict;
@@ -208,6 +226,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('ohm');
 
+1;
 
 package Physics::Unit::Speed;
 use strict;
@@ -217,6 +236,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('mps');
 
+1;
 
 package Physics::Unit::Substance;
 use strict;
@@ -236,6 +256,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('kelvin');
 
+1;
 
 package Physics::Unit::Time;
 use strict;
@@ -245,6 +266,7 @@ use vars qw( @ISA $MyUnit );
 
 $MyUnit = GetUnit('second');
 
+1;
 
 package Physics::Unit::Volume;
 use strict;
@@ -255,16 +277,15 @@ use vars qw( @ISA $MyUnit );
 $MyUnit = GetUnit('liter');
 
 1;
-
 __END__
 
 =head1 NAME
 
-Physics::Unit::ScalarSubtypes - User defined dimensional units.
+Physics::Unit::Unit::ScalarSubtypes - User defined dimensional units.
 
 =head1 AUTHOR
 
-Chris Maloney <Dude@chrismaloney.com>
+Chris Maloney <Dude@ChrisMaloney.com>
 
 =head1 COPYRIGHT AND LICENSE
 
